@@ -272,6 +272,7 @@ __all__ = (
     "StartSessionResponseTypeDef",
     "StepExecutionFilterTypeDef",
     "TerminateSessionResponseTypeDef",
+    "UnlabelParameterVersionResultTypeDef",
     "UpdateAssociationResultTypeDef",
     "UpdateAssociationStatusResultTypeDef",
     "UpdateDocumentDefaultVersionResultTypeDef",
@@ -968,6 +969,9 @@ _OptionalInstancePatchStateTypeDef = TypedDict(
         "NotApplicableCount": int,
         "LastNoRebootInstallOperationTime": datetime,
         "RebootOption": Literal["RebootIfNeeded", "NoReboot"],
+        "CriticalNonCompliantCount": int,
+        "SecurityNonCompliantCount": int,
+        "OtherNonCompliantCount": int,
     },
     total=False,
 )
@@ -2339,6 +2343,9 @@ DescribePatchGroupStateResultTypeDef = TypedDict(
         "InstancesWithFailedPatches": int,
         "InstancesWithNotApplicablePatches": int,
         "InstancesWithUnreportedNotApplicablePatches": int,
+        "InstancesWithCriticalNonCompliantPatches": int,
+        "InstancesWithSecurityNonCompliantPatches": int,
+        "InstancesWithOtherNonCompliantPatches": int,
     },
     total=False,
 )
@@ -3076,6 +3083,12 @@ TerminateSessionResponseTypeDef = TypedDict(
     "TerminateSessionResponseTypeDef", {"SessionId": str}, total=False
 )
 
+UnlabelParameterVersionResultTypeDef = TypedDict(
+    "UnlabelParameterVersionResultTypeDef",
+    {"RemovedLabels": List[str], "InvalidLabels": List[str]},
+    total=False,
+)
+
 UpdateAssociationResultTypeDef = TypedDict(
     "UpdateAssociationResultTypeDef",
     {"AssociationDescription": "AssociationDescriptionTypeDef"},
